#
# spec file for package python-Markdown
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Markdown
Version:        2.6.11
Release:        lp150.2.1
Summary:        Python implementation of Markdown
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://packages.python.org/Markdown/
Source:         https://files.pythonhosted.org/packages/source/M/Markdown/Markdown-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-xml
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
# older python2 version provided the package in lowercase
Provides:       %{oldpython}-markdown = %{version}
Obsoletes:      %{oldpython}-markdown < %{version}
%endif
%python_subpackages

%description
This is a Python implementation of John Gruber's [Markdown][].
It is almost completely compliant with the reference implementation,
though there are a few known issues. See [Features][] for information
on what exactly is supported and what is not. Additional features are
supported by the [Available Extensions][].

%prep
%setup -q -n Markdown-%{version}

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%python_clone -a %{buildroot}%{_bindir}/markdown_py

%check
%python_exec run-tests.py

%post
%python_install_alternative markdown_py

%postun
%python_uninstall_alternative markdown_py

%files %{python_files}
%license LICENSE.md
%doc README.md docs/*
%python_alternative %{_bindir}/markdown_py
%{python_sitelib}/Markdown-%{version}-py%{python_version}.egg-info
%{python_sitelib}/markdown

%changelog
* Mon Mar 19 2018 tchvatal@suse.com
- Add build/runtime dependency over setuptools wrt bsc#1079287
- Remove python-devel dependency which is not really needed
* Fri Jan  5 2018 benoit.monin@gmx.fr
- update to version 2.6.11: bugfix release
  * Added a new BACKLINK-TITLE option to the footnote extension so
    that non-English users can provide a custom title to back links
    (see #610)
- additional changes from version 2.6.10: documentation update
- remove encoding conversion: fixed upstream
* Fri Aug 18 2017 benoit.monin@gmx.fr
- update to version 2.6.9: bugfix release
* Sun May  7 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
- fix encoding of the single file with CR/LF:
  avoid python-bytecode-inconsistent-mtime in every other files
* Thu Jan 26 2017 benoit.monin@gmx.fr
- update to version 2.6.8: bugfix release
* Sat Sep 24 2016 benoit.monin@gmx.fr
- update to version 2.6.7: bugfix release
- change source url to files.pythonhosted.org
* Wed Mar 23 2016 benoit.monin@gmx.fr
- update to version 2.6.6: no upstream changelog
* Wed Nov 25 2015 benoit.monin@gmx.fr
- update to version 2.6.5: bugfix release
* Sat Nov  7 2015 benoit.monin@gmx.fr
- update to version 2.6.4: bugfix release
* Tue Oct 27 2015 benoit.monin@gmx.fr
- update to version 2.6.3: bugfix release
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to version 2.6.2: bugfix release
* Tue Mar 10 2015 benoit.monin@gmx.fr
- update to version 2.6.1: bugfix release
  The (new) yaml option has been removed from the Meta-Data
  Extension as it was buggy
* Fri Feb 20 2015 benoit.monin@gmx.fr
- update to version 2.6:
  * `safe_mode` Deprecated
  * Positional Arguments Deprecated
  * "Shortened" Extension Names Deprecated
  * Extension Configuration as Part of Extension Name Deprecated
  * HeaderId Extension Pending Deprecation
  * The `configs` Keyword is Deprecated
  * Official Support for PyPy
  * YAML Style Meta-Data
  * Table of Contents Extension Refactored
  * Pygments can now be disabled
  * Miscellaneous
* Mon Nov 24 2014 benoit.monin@gmx.fr
- update to version 2.5.2: bugfix release
* Fri Oct  3 2014 benoit.monin@gmx.fr
- update to version 2.5.1: bugfix release
* Tue Sep 16 2014 benoit.monin@gmx.fr
- update to version 2.5:
  * The force_linenos config key on the CodeHilite extension has
    been deprecated.
  * Both safe_mode and the associated html_replacement_text
    keywords will be deprecated in version 2.6.
  * Positional arguments on the markdown.Markdown() function are
    pending deprecation.
  * The builtin extensions did not require the full path to be
    provided. This behavior will be deprecated in version 2.6.
  * The previously documented method of appending the extension
    configs as a string to the extension name will be deprecated in
    version 2.6.
  * The Smarty extension has had a number of additional
    configuration settings added.
  * Named extensions can now point to any module and/or Class on
    your PYTHONPATH.
  * The extension configuration code has been refactored.
  * The command line interface now accepts a --extensions_config
    (or -c).
  * The amonition extension is no longer considered experimental.
  * Various bug fixes have been made.
- add python-PyYAML to BuildRequires: needed for tests
* Wed Jul  9 2014 i@marguerite.su
- fix conflicts with python3-Markdown
  * both use update-alternatives
* Mon May 26 2014 hpj@urpla.net
- disable tests for 11.1 and SLES 10 builds
* Mon Feb 17 2014 benoit.monin@gmx.fr
- update to version 2.4:
  * the "force_linenos" config setting of the CodeHilite extension
    has been marked as Deprecated.
  * URLs are no longer percent-encoded.
  * the Smarty Extension has been added, which implements
    SmartyPants.
  * the Table of Contents Extension now supports new permalink
    option for creating Sphinx-style anchor links.
  * it is now possible to enable Markdown formatting inside HTML
    blocks by appending `markdown=1` to opening tag attributes.
  * The code blocks now support emphasizing some of the code lines.
  * Various bug fixes have been made.
- fix CRLF in all files: upstream converted to DOS encoding
* Wed Jan 15 2014 benoit.monin@gmx.fr
- update to version 2.3.1:
  no changelog
- additional changes from version 2.3.0:
  * Support has been dropped for Python 2.5.
  * All classes are now "new-style" classes.
  * "safe_mode" has been further restricted.
  * The ids assigned to footnotes now contain a dash (`-`) rather
    than a colon (`:`) when `output_format` it set to "html5" or
    "xhtml5".
  * The "force_linenos" config setting of the CodeHilite extension
    has been marked as Pending Deprecation and a new setting
    "linenums" has been added to replace it.
  * The "RSS" extension has been removed.
  * The "HTML Tidy" Extension has been removed.
  * The entire code base now universally runs in Python 2 and
    Python 3 without any need for running the 2to3 conversion tool.
  * The Admonition Extension has been added.
  * Various bug fixes have been made.
- drop sed call to remove shebangs: fixed upstream
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 2.2.1:
  + Python-Markdown 2.2.1 is a bug-fix release. No new features have been added.
    However, at least one bug fix does not work in Python 2.4 so that version of
    Python is no longer supported. For a full list of changes, see the git log.
* Mon Jul 23 2012 saschpe@suse.de
- Initial version
